from distutils.core import setup

setup(
    name         ='xyz_tools',
    version      ='1.0.0',
    py_modules   =['xyz_tools'],
    author       ='bowen xu',
    author_email ='575650581@qq.com',
    description  ='frequently-used tools',
    )